@@ -60,6 +60,12 @@ private slots:
 
     void openArticleFromLink(QListWidgetItem *item);
 
+    void on_searchLineEdit_textChanged(const QString &arg1);
+
+    void on_searchLineEdit_returnPressed();
+
+    void removePlaylistsMode();
+
 private:
     Ui::MainWindow *ui;
     ArticleList *articleList;
