@@ -13,7 +13,9 @@ Player::Player(QWidget *parent) :
     reload = false;
     playing = false;
     audio = new Audio();
-    //connect(audio,SIGNAL(finished()), this, SLOT(playingFinished()));
+
+    connect(audio,SIGNAL(finished()), this, SLOT(playingFinished()));
+    connect(audio, SIGNAL(wavCreated()), this, SLOT(wavCreated()));
 }
 
 Player::~Player()
@@ -145,3 +147,8 @@ void Player::playingFinished()
 {
     playing = false;
 }
+
+void Player::wavCreated()
+{
+    this->audioCreated();
+}
