@@ -39,8 +39,11 @@ private slots:
 
     void playingFinished();
 
+    void wavCreated();
+
 signals:
     void openArticleFromLink(QListWidgetItem *item);
+    void audioCreated();
 
 private:
     Ui::Player *ui;
