@@ -1,11 +1,7 @@
 #include "playlist.h"
 #include "ui_playlist.h"
 #include <QMap>
-#define NORMAL "normal"
-#define REMOVE "remove"
-#ifdef Q_WS_MAEMO5
-#include <QtMaemo5/QMaemo5InformationBox>
-#endif
+
 
 Playlist::Playlist(QWidget *parent) :
     QWidget(parent),
@@ -15,7 +11,7 @@ Playlist::Playlist(QWidget *parent) :
     playlistlist = new Playlists();
     this->updateList();
     ui->treeWidget->setColumnCount(1);
-    mode = NORMAL;
+
 
 
 
@@ -28,7 +24,8 @@ Playlist::~Playlist()
 
 void Playlist::on_treeWidget_itemClicked(QTreeWidgetItem *item, int column)
 {
-    if (mode == NORMAL)
+
+    if (column == 0)
     {
         if (item->childCount() == 0)
             this->articleSelected(item, column);
@@ -38,18 +35,17 @@ void Playlist::on_treeWidget_itemClicked(QTreeWidgetItem *item, int column)
 
         this->hide();
     }
-    if (mode == REMOVE)
+    if (column == 1)
     {
         if (item->childCount() == 0)
-            playlistlist->removePlaylistItem(item, column, item->parent());
+            playlistlist->removePlaylistItem(item->data(1, 1).toString(), column, item->parent());
 
         else
             playlistlist->removePlaylist(item->text(column));
 
         this->updateList();
-        mode = NORMAL;
-       // this->hide();
     }
+
 }
 
 QStringList Playlist::getPlaylists()
@@ -67,26 +63,22 @@ void Playlist::updateList()
 {
     this->ui->treeWidget->clear();
     QList<QTreeWidgetItem *> items;
+    QList<QTreeWidgetItem *> removes;
     foreach(QString title, this->playlistlist->getPlaylistTitles())
     {
+        QTreeWidgetItem *itemRemove = new QTreeWidgetItem(QStringList("Remove"));
+        itemRemove->setData(1, 1, QVariant(title));
         QTreeWidgetItem *item = new QTreeWidgetItem(QStringList(title));
         QList<QTreeWidgetItem*> children;
         foreach (QString article, this->playlistlist->getPlaylistContent(title))
             children.append(new QTreeWidgetItem(QStringList(article)));
         item->addChildren(children);
         items.append(item);
+        removes.append(itemRemove);
        // item->set
         //this->ui->treeWidget->addTopLevelItem(item);
     }
     this->ui->treeWidget->insertTopLevelItems(0, items);
-}
-
-void Playlist::setMode(QString mode)
-{
-    this->mode = mode;
-    #ifdef Q_WS_MAEMO5
-    QMaemo5InformationBox::information(this, "Remove playlists or playlist items by clicking on them",
-                                                QMaemo5InformationBox::DefaultTimeout);
-    #endif
+    this->ui->treeWidget->insertTopLevelItems(1, removes);
 }
 
