@@ -51,14 +51,14 @@ void Playlists::addNewItemToPlaylist(QString title, QString item)
 
 }
 
-void Playlists::removePlaylistItem(QTreeWidgetItem *item, int column, QTreeWidgetItem *parent)
+void Playlists::removePlaylistItem(QString item, int column, QTreeWidgetItem *parent)
 {
     QStringList items;
     items = playlists.take(parent->text(column));
     int i = 0;
     foreach (QString playlistItem, items)
     {
-        if (playlistItem == item->text(column))
+        if (playlistItem == item)
         {
             items.removeAt(i);
             break;
